@@ -44,7 +44,8 @@ default_args = [
 
 import site
 
-DOWNLOADS_FOLDER = Path(site.getsitepackages()[1]) /'chromium_binary_lambda-local-chromium'
+teste =site.getsitepackages()
+DOWNLOADS_FOLDER = Path(site.getsitepackages()[1]) /'chromium_binary_lambda'/ 'local-chromium'
 DOWNLOAD_HOST = 'https://storage.googleapis.com'
 BASE_URL = f'{DOWNLOAD_HOST}/chromium-browser-snapshots'
 
